@@ -3,6 +3,7 @@ package exporter
 import (
 	"fmt"
 	"net/http"
+	"net/url"
 	"runtime"
 	"strconv"
 	"strings"
@@ -268,6 +269,7 @@ func NewRedisExporter(redisURI string, opts Options) (*Exporter, error) {
 			"total_net_output_bytes": "net_output_bytes_total",
 
 			"expired_keys":    "expired_keys_total",
+			"cached_keys":     "cached_keys_total",
 			"evicted_keys":    "evicted_keys_total",
 			"keyspace_hits":   "keyspace_hits_total",
 			"keyspace_misses": "keyspace_misses_total",
@@ -286,6 +288,9 @@ func NewRedisExporter(redisURI string, opts Options) (*Exporter, error) {
 			"io_threaded_reads_processed":  "io_threaded_reads_processed",
 			"io_threaded_writes_processed": "io_threaded_writes_processed",
 			"dump_payload_sanitizations":   "dump_payload_sanitizations",
+
+			"storage_provider_read_hits":   "storage_provider_read_hits",
+			"storage_provider_read_misses": "storage_provider_read_misses",
 		},
 	}
 
@@ -342,6 +347,7 @@ func NewRedisExporter(redisURI string, opts Options) (*Exporter, error) {
 		"commands_failed_calls_total":                  {txt: `Total number of errors prior command execution per command`, lbls: []string{"cmd"}},
 		"commands_rejected_calls_total":                {txt: `Total number of errors within command execution per command`, lbls: []string{"cmd"}},
 		"commands_total":                               {txt: `Total number of calls per command`, lbls: []string{"cmd"}},
+		"latency_percentiles_usec":                     {txt: `A summary of latency percentile distribution per command`, lbls: []string{"cmd"}},
 		"config_key_value":                             {txt: `Config key and value`, lbls: []string{"key", "value"}},
 		"config_value":                                 {txt: `Config key and value as metric`, lbls: []string{"key"}},
 		"connected_clients_details":                    {txt: "Details about connected clients", lbls: connectedClientsLabels},
@@ -350,6 +356,7 @@ func NewRedisExporter(redisURI string, opts Options) (*Exporter, error) {
 		"db_avg_ttl_seconds":                           {txt: "Avg TTL in seconds", lbls: []string{"db"}},
 		"db_keys":                                      {txt: "Total number of keys by DB", lbls: []string{"db"}},
 		"db_keys_expiring":                             {txt: "Total number of expiring keys by DB", lbls: []string{"db"}},
+		"db_keys_cached":                               {txt: "Total number of cached keys by DB", lbls: []string{"db"}},
 		"errors_total":                                 {txt: `Total number of errors per error type`, lbls: []string{"err"}},
 		"exporter_last_scrape_error":                   {txt: "The last scrape error status.", lbls: []string{"err"}},
 		"instance_info":                                {txt: "Information about the Redis instance", lbls: []string{"role", "redis_version", "redis_build_id", "redis_mode", "os", "maxmemory_policy", "tcp_port", "run_id", "process_id"}},
@@ -373,6 +380,7 @@ func NewRedisExporter(redisURI string, opts Options) (*Exporter, error) {
 		"sentinel_master_sentinels":                    {txt: "The number of sentinels monitoring this master", lbls: []string{"master_name", "master_address"}},
 		"sentinel_master_slaves":                       {txt: "The number of slaves of the master", lbls: []string{"master_name", "master_address"}},
 		"sentinel_master_status":                       {txt: "Master status on Sentinel", lbls: []string{"master_name", "master_address", "master_status"}},
+		"sentinel_master_ckquorum_status":              {txt: "Master ckquorum status", lbls: []string{"master_name", "message"}},
 		"sentinel_masters":                             {txt: "The number of masters this sentinel is watching"},
 		"sentinel_running_scripts":                     {txt: "Number of scripts in execution right now"},
 		"sentinel_scripts_queue_length":                {txt: "Queue of user scripts to execute"},
@@ -527,7 +535,14 @@ func (e *Exporter) scrapeRedisHost(ch chan<- prometheus.Metric) error {
 	e.registerConstMetricGauge(ch, "exporter_last_scrape_connect_time_seconds", connectTookSeconds)
 
 	if err != nil {
-		log.Errorf("Couldn't connect to redis instance")
+		var redactedAddr string
+		if redisURL, err2 := url.Parse(e.redisAddr); err2 != nil {
+			log.Debugf("url.Parse( %s ) err: %s", e.redisAddr, err2)
+			redactedAddr = "<redacted>"
+		} else {
+			redactedAddr = redisURL.Redacted()
+		}
+		log.Errorf("Couldn't connect to redis instance (%s)", redactedAddr)
 		log.Debugf("connectToRedis( %s ) err: %s", e.redisAddr, err)
 		return err
 	}
